@@ -4,7 +4,7 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.19';
+our $VERSION = '0.20';
 
 # import params is just one 'no-unicode-escape-permanently'
 # if set, then unicode escaping will not happen at
@@ -617,7 +617,7 @@ Data::Roundtrip - convert between Perl data structures, YAML and JSON with unico
 
 =head1 VERSION
 
-Version 0.19
+Version 0.20
 
 =head1 SYNOPSIS
 
@@ -694,6 +694,13 @@ format (not spaces, indendation or line breaks).
     my $json_with_unicode_escaped =
           json2json($jsonstr, {'escape-unicode'=>1});
 
+    # With version 0.18 and up two more exported-on-demand
+    # subs were added to read JSON or YAML directly from a file:
+    # jsonfile2perl() and yamlfile2perl()
+    my $perldata = jsonfile2perl("file.json");
+    my $perldata = yamlfile2perl("file.yaml");
+    die "failed" unless defined $perldata;
+
     # For some of the above functions there exist command-line scripts:
     perl2json.pl -i "perl-data-structure.pl" -o "output.json" --pretty
     json2json.pl -i "with-unicode.json" -o "unicode-escaped.json" --escape-unicode
